==> PGSEA_1.10.0.zip: PGSEA/doc/PGSEA.R <==
###################################################
### chunk number 1: 
###################################################
	library(PGSEA)
	basic <- new("smc",ids=c("gene a","gene b"),reference="simple smc")
	str(basic)


###################################################
### chunk number 2: 
###################################################
	datadir <- system.file("data", package = "PGSEA")
	sample <- readGmt(file.path(datadir, "sample.gmt"))
	str(sample[1])


###################################################
### chunk number 3: 
###################################################

	data(nbEset)
	pg <- PGSEA(nbEset,cl=sample,ref=1:5)


###################################################
### chunk number 4: 
###################################################
	sub <- factor(c(rep(NA,5),rep("NeuroB",5),rep("NeuroB_MYC+",5)))
	smcPlot(pg[,],sub,scale=c(-12,12),show.grid=T,margins=c(1,1,7,13),col=.rwb)
	


###################################################
### chunk number 5: 
###################################################
	mcs <- go2smc()[1:10]
	pg <- PGSEA(nbEset,cl=mcs,ref=1:5)
	


###################################################
### chunk number 6: 
###################################################

	smcPlot(pg[,],sub,scale=c(-12,12),show.grid=T,margins=c(1,1,7,20),col=.rwb)
	


###################################################
### chunk number 7: 
###################################################
	#data(VAImcs)
	data(VAIgsc)
  pg <- PGSEA(nbEset,cl=VAIgsc,ref=1:5)
	


###################################################
### chunk number 8: 
###################################################

	smcPlot(pg[,],sub,scale=c(-5,5),show.grid=T,margins=c(1,1,8,14),col=.rwb,r.cex=.7)

==> PGSEA_1.20.1.zip: PGSEA/doc/PGSEA.R <==
###################################################
### chunk number 1: 
###################################################
#line 41 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpOGU2WQ/R.INSTALL1c233795/PGSEA/inst/doc/PGSEA.Rnw"
	library(PGSEA)
	basic <- new("smc",ids=c("gene a","gene b"),reference="simple smc")
	str(basic)


###################################################
### chunk number 2: 
###################################################
#line 51 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpOGU2WQ/R.INSTALL1c233795/PGSEA/inst/doc/PGSEA.Rnw"
	datadir <- system.file("data", package = "PGSEA")
	sample <- readGmt(file.path(datadir, "sample.gmt"))
	str(sample[1])


###################################################
### chunk number 3: 
###################################################
#line 59 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpOGU2WQ/R.INSTALL1c233795/PGSEA/inst/doc/PGSEA.Rnw"

	data(nbEset)
	pg <- PGSEA(nbEset,cl=sample,ref=1:5)


###################################################
### chunk number 4: 
###################################################
#line 67 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpOGU2WQ/R.INSTALL1c233795/PGSEA/inst/doc/PGSEA.Rnw"
	sub <- factor(c(rep(NA,5),rep("NeuroB",5),rep("NeuroB_MYC+",5)))
	smcPlot(pg[,],sub,scale=c(-12,12),show.grid=T,margins=c(1,1,7,13),col=.rwb)
	


###################################################
### chunk number 5: 
###################################################
#line 78 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpOGU2WQ/R.INSTALL1c233795/PGSEA/inst/doc/PGSEA.Rnw"
	mcs <- go2smc()[1:10]
	pg <- PGSEA(nbEset,cl=mcs,ref=1:5)
	


###################################################
### chunk number 6: 
###################################################
#line 86 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpOGU2WQ/R.INSTALL1c233795/PGSEA/inst/doc/PGSEA.Rnw"

	smcPlot(pg[,],sub,scale=c(-12,12),show.grid=T,margins=c(1,1,7,20),col=.rwb)
	


###################################################
### chunk number 7: 
###################################################
#line 99 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpOGU2WQ/R.INSTALL1c233795/PGSEA/inst/doc/PGSEA.Rnw"
	#data(VAImcs)
	data(VAIgsc)
  pg <- PGSEA(nbEset,cl=VAIgsc,ref=1:5)
	


###################################################
### chunk number 8: 
###################################################
#line 108 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpOGU2WQ/R.INSTALL1c233795/PGSEA/inst/doc/PGSEA.Rnw"

	smcPlot(pg[,],sub,scale=c(-5,5),show.grid=T,margins=c(1,1,8,14),col=.rwb,r.cex=.7)
